km3modules.k40.SummaryMedianPMTRateService
==========================================

.. currentmodule:: km3modules.k40

.. autoclass:: SummaryMedianPMTRateService

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SummaryMedianPMTRateService.__init__
      ~SummaryMedianPMTRateService.add
      ~SummaryMedianPMTRateService.configure
      ~SummaryMedianPMTRateService.expose
      ~SummaryMedianPMTRateService.finish
      ~SummaryMedianPMTRateService.get
      ~SummaryMedianPMTRateService.get_median_rates
      ~SummaryMedianPMTRateService.pre_finish
      ~SummaryMedianPMTRateService.process
      ~SummaryMedianPMTRateService.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SummaryMedianPMTRateService.name
   
   